clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% FIG1
%   
%=========================================================================================================

% download frezchem phase diagram
fc = read_frezchem

%==============================================================================
% Plots
%==============================================================================
%
%==================================================================================================
%
% Phase diagram
%
%==================================================================================================

figure; hold on; box on
set(gca,'yscale','log')

i_S = 6
zarr = 1 - fc.phi_ice(i_S,:);
plot(fc.T,zarr*1000., 'k', 'LineWidth', 2);

zarr = 1 - fc.phi_ice(i_S,:) - fc.phi_H2O_min(i_S,:);
plot(fc.T,zarr*1000.,'b');

zarr = 1 - fc.phi_ice(i_S,:) - fc.phi_H2O_min(i_S,:) - fc.phi_salt_min(i_S,:);
plot(fc.T,zarr*1000., 'k', 'LineWidth', 2);

zmf     = fc.phi_salt_liq(i_S,:) % - (zmf_Cl - zmf_Na - zmf_SO4) .* zphi
plot(fc.T,zmf*1000.,'b'); % g/kg

plot([-6.2 -6.2],[0.5 1001.], 'k:')
plot([-6.4 -6.4],[0.5 1001.], 'k:')
plot([-22.9 -22.9],[0.5 1001.], 'k:')
plot([-33.3 -33.3],[0.5 1001.], 'k:')
plot([-33.4 -33.4],[0.5 1001.], 'k:')
plot([-36.3 -36.3],[0.5 1001.], 'k:')

ylim([0.5 1000.])
xlim([-36.3 0.])
xlabel('T(C)')
ylabel('mass fraction (g/kg)')

set(gca,'fontsize', 16)
set(gca, 'FontName', 'Helvetica LT Std')
set(gca, 'YAxisLocation', 'right');

%==================================================================================================


