clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% FIG3
%   
%=========================================================================================================

T_eutectic = -36.2000000000000000;
S_eutectic = S_liquidus(T_eutectic,3);

%
%---------------------------------------------------------------------------------------------------------
%  Get Observations;
%---------------------------------------------------------------------------------------------------------
%
[ Sbr_obs, T_obs, S_G37, T_G37, S_B16, T_B16, S_NT54, T_NT54, S_DK74, T_DK74 ] = ...
    liquidus_obs(T_eutectic); % get retained observations, truncating hypo-eutectic values

%
%---------------------------------------------------------------------------------------------------------
% Sbr vs T plot
%---------------------------------------------------------------------------------------------------------
%
figure; hold on; box on

% absix
T_01K = -36.2:0.01:0; %0.1 K Temperatures
T_1K  = -36.2:0;      %1.0 K Temperatures
Sbr_1gkg = 0:350;

% draw rectangle
v = [-6. 0.; 0. 0.; 0. 120.; -6. 120.];
f = [1 2 3 4];
patch('Faces',f,'Vertices',v,'FaceColor', [0. 0.5 0.], 'FaceAlpha', 0.1)

% put data
h5  = plot( T_01K, S_liquidus(T_01K,3), 'k', 'LineWidth', 2 );    % POLY3
h6  = plot( T_freeze(Sbr_1gkg,4), Sbr_1gkg,  'b--', 'LineWidth', 1 );  % TEOS-10 extended
h7  = plot( T_01K, S_liquidus(T_01K,5), 'b', 'LineWidth', 2 );    % TEOS-10 modified
h8  = plot( T_01K, S_liquidus(T_01K,1), 'r--', 'LineWidth', 1 );  % Assur 58
h9  = plot( T_01K, S_liquidus(T_01K,2), 'r', 'LineWidth', 2 );    % NW09
h10 = plot( T_01K, S_liquidus(T_01K,6), 'Color', [ 1. 0.82 0.13 ], 'LineWidth', 1.5 ); % CW86

h11 = plot( T_1K, S_liquidus(T_1K,7), 'ko', 'MarkerFaceColor', [0.5 0.5 0.5], 'MarkerSize', 8.); %FREZCHEM

h1  = plot(T_DK74, S_DK74, 'ko', 'MarkerFaceColor', [ 0. 0. 0. ], 'MarkerSize', 6.);    % Doherty Kester 74
h2  = plot(T_G37, S_G37, 'ksq', 'MarkerFaceColor', [ 1. 1. 1.], 'MarkerSize', 10.);     % Gitterman 37
h3  = plot(T_NT54, S_NT54, 'ksq', 'MarkerFaceColor', [ 1. 0. 0.0], 'MarkerSize', 10.);  % Nelson Thompson 54
h4  = plot(T_B16   , S_B16, 'ksq', 'MarkerFaceColor', [ 0. 0. 1.0], 'MarkerSize', 10.); % Butler et al. 2016

% mirabilite precipitation curve
h12 = plot( [-6.3 -6.3], [0. 350], 'k--', 'Color', [0.2 0.2 1.])
h13 = plot( [-22.9 -22.9], [0. 350], 'k--', 'Color', [0.2 0.2 1.])
text(-7.4, 180., 'Mirabilite (Na_2SO_4\cdot10H_2O)', 'Rotation', 90.,'Color', [0.2 0.2 1.], 'FontSize', 12.)
text(-24, 125., 'Hydrohalite (NaCl\cdot2H_2O)', 'Rotation', 90.,'Color', [0.2 0.2 1.], 'FontSize', 12.)

% Eutectic point
h14 = plot(T_eutectic,S_eutectic,'kp','MarkerFaceColor', [1. 0.3 0.3], 'MarkerSize', 10.)
text(T_eutectic-1.5,S_eutectic-25.,'(T_e,S_e)', 'Color', [1. 0.3 0.3], 'FontSize', 12., 'FontWeight', 'Bold')

% Axis properties & legends
ylim([0. 350.]); xlim([-38. 0.])

legend([h1 h2 h3 h4 ...
        h11 ...
        h8 h9 h5 h6 h7 h10 ], ...
{ 'Doherty and Kester (1974)', 'Gitterman (1937)', 'Nelson and Thompson (1954)', 'Butler et al. (2016)' , ...
  'FREZCHEM', ...
  'Linear Fit (A58)', '3-o. Fit (NW09)', ...
  '3-o. Fit (POLY3)', 'eTEOS-10', 'mTEOS-10', '3-o. piecewise (CW86)'})
    
xlabel('T (C)'); ylabel('S_{br} (g/kg)')
set(gca,'fontsize', 20)
set(gca, 'FontName', 'Helvetica LT Std')

text(-35., 325., '(a)', 'Fontsize', 20, 'FontWeight', 'Bold')

% unesco78 freezing point (odile)
%Tfr_U78 = -0.0575 * Sbr_1gkg + 1.710523e-3 * sqrt( Sbr_1gkg.^3 ) ...
        %- 2.15499e-4 * Sbr_1gkg.^2 - 7.5310e-4 * 10.13
    %h14  = plot( Tfr_U78, Sbr_1gkg,  'y--', 'LineWidth', 1 );  % Unesco 78

%
%---------------------------------------------------------------------------------------------------------
% Sbr-Sobs difference vs T plot
%---------------------------------------------------------------------------------------------------------
%
figure

i_Sbr = [ 7 3 5 6 ];
ztitle = [ {'(b) FREZCHEM'} {'(c) POLY3'} {'(d) mTEOS-10'} {'(e) CW86'}];

for i = 1:4
    subplot(4,1,i); hold on; box on
    zSbr = S_liquidus(T_DK74,i_Sbr(i));
    plot(T_DK74,zSbr-S_DK74,'ko', 'MarkerFaceColor', [ 0. 0. 0. ], 'MarkerSize', 2.)
    zSbr = S_liquidus(T_G37,i_Sbr(i));
    plot(T_G37,zSbr-S_G37,'ksq', 'MarkerFaceColor', [ 1. 1. 1.], 'MarkerSize', 5.)
    zSbr = S_liquidus(T_NT54,i_Sbr(i));
    plot(T_NT54,zSbr-S_NT54, 'ksq', 'MarkerFaceColor', [ 1. 0. 0.], 'MarkerSize', 5.)
    zSbr = S_liquidus(T_B16,i_Sbr(i));
    plot(T_B16,zSbr-S_B16, 'ksq', 'MarkerFaceColor', [ 0. 0. 1.], 'MarkerSize', 5.)
    
    text(-35.0,10.,ztitle(i),'FontSize', 12, 'FontWeight', 'Bold')
    set(gca,'fontsize', 12)
    set(gca, 'FontName', 'Helvetica LT Std')
    ylim([-15 15]); xlim([-36 0]); yticks([-15 -10 -5 0 5 10 15])
    plot([-36.2 0], [0. 0.], 'k:')
end
xlabel('T(C)'); 
ylabel('S_{br}(T^{obs})-S_{br}^{obs} (g/kg) ')

% draw rectangles
v = [-2. -500.; 0. -500.; 0. 500.; -2. 500.];
f = [1 2 3 4];
hpatch = patch('Faces',f,'Vertices',v,'FaceColor', [0.5 0. 0.], 'FaceAlpha', 0.1)
hh1 = hatchfill(hpatch, 'single', -45, 3);