clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% FIG4
%   
%=========================================================================================================

unit_fac = 1000.;
c_unit = 'g/kg';

% read FREZCHEM
fc = read_frezchem;

% compare brine mass and liquid H2O fraction
disp({' * Link between liquid H2O and liquid mass fraction * '})
zdiff     = fc.phi_H2O_liq - fc.phi_liq;
disp({' Mean Bias     : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' Relative bias : ', mean2(zdiff./fc.phi_liq)*100., '%'}  )
disp({' RMSE          : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE          : ', std2(zdiff)* unit_fac, c_unit} )
[zcorr, zp] = corrcoef(fc.phi_H2O_liq,fc.phi_liq,'rows','pairwise');
disp({' correlation coefficient R : ', zcorr(1,2)})
disp({' determination coefficient R (percentage of variance): ', zcorr(1,2)*zcorr(1,2)})
format long
disp({' p-value : ', num2str(zp(1,2),'%2.1e')})

% figure;
% subplot(1,2,1); plot(fc.phi_liq,zdiff,'ko', 'MarkerFaceColor', 'k', 'MarkerSize', 1)     , xlabel('\phi_{br}'); ylabel('\phi_{H_2O} - \phi_{br} (g/kg)')
% subplot(1,2,2); plot(fc.phi_liq,zdiff./fc.phi_liq*100.,'ko', 'MarkerFaceColor', 'k', 'MarkerSize', 1) , xlabel('\phi_{br}'); ylabel('\phi_{H2O} - \phi_{br} (%)')

figure;
subplot(1,2,1)
plot(fc.phi_liq*unit_fac,fc.phi_H2O_liq*unit_fac,'ko', 'MarkerFaceColor', 'k', 'MarkerSize', 1);
xlabel('\phi_{br} (g/kg)'); ylabel('\phi_{H_2O} (g/kg)')
hold on; plot([0.1 1000.], [0.1 1000.], 'r--')
set(gca,'Xscale','log')
set(gca,'Yscale','log')

% compare brine mass and volume fraction
TT = zeros(41,363);
for i = 1:41
    TT(i,:) = fc.T;
end
rhoi         =   917.0 - 0.1403 * TT; % Pounder (update into TEOS-10 maybe)
rhobr        =   1000 + 0.8*fc.S_br;       % CW83    (update into TEOS-10)
zr           =   rhobr ./ rhoi;
zden         =   1. + ( 1. ./ fc.phi_liq - 1 ) .* zr;
fc.phi_liq_v =   1. ./ zden;

disp({' * Link between volume and mass fraction * '})
zdiff     = fc.phi_liq_v - fc.phi_liq;
disp({' Mean Bias     : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' Relative bias : ', mean2(zdiff./fc.phi_liq)*100., '%'}  )
disp({' RMSE          : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE          : ', std2(zdiff)* unit_fac, c_unit} )
[zcorr, zp] = corrcoef(fc.phi_H2O_liq,fc.phi_liq,'rows','pairwise');
disp({' correlation coefficient R : ', zcorr(1,2)})
disp({' determination coefficient R (percentage of variance): ', zcorr(1,2)*zcorr(1,2)})
format long
disp({' p-value : ', num2str(zp(1,2),'%2.1e')})

subplot(1,2,2)
plot(fc.phi_liq*unit_fac,fc.phi_liq_v*unit_fac,'ko', 'MarkerFaceColor', 'k', 'MarkerSize', 1);
xlabel('\phi_{br} (g/kg)'); ylabel('\phi^v_{br} (g/kg)')
hold on; plot([0.1 1000.], [0.1 1000.], 'r--')
set(gca,'Xscale','log')
set(gca,'Yscale','log')

% figure
% subplot(1,2,1); plot(fc.phi_liq,zdiff,'ko', 'MarkerFaceColor', 'k', 'MarkerSize', 1)     , xlabel('\phi_{br}'); ylabel('\phi^v_{br} - \phi_{br} (g/kg)')
% subplot(1,2,2); plot(fc.phi_liq,zdiff./fc.phi_liq*100.,'ko', 'MarkerFaceColor', 'k', 'MarkerSize', 1) , xlabel('\phi_{br}'); ylabel('\phi^v_{br} - \phi_{br} (%)')



