clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% FIGA1
%   
%=========================================================================================================


clear all
close all

i_opt = 2; % option on gc shape

T_eutectic = -36.2;
S_eutectic = S_liquidus(T_eutectic,3);

T=(T_eutectic:1.:0.)   ; zs = size(T)  ; NT = zs(2);
Sbr=(0:1.:S_eutectic)' ; zs = size(Sbr); NS = zs(1);

[TT,SS] = meshgrid(T,Sbr);

mu_br1 = gsw_chem_potential_water_t_exact(SS,TT,0.); % best computation!!!
mu_br1 = mu_br1*1000.; % conversion to J/kg

mu_ice = gsw_gibbs_ice(0,0,TT,0.);

%-------------------------------
% Compute correction deltamu(S)
%-------------------------------

% 2D version
ztfp   = T_freeze(SS,3);
ztf10  = T_freeze(SS,5);
zterm1 = gsw_gibbs_ice(0,0,ztfp,0.);
zterm2 = gsw_gibbs_ice(0,0,ztf10,0.);

dmu_w_2d = zterm1 - zterm2;

% 1D version
clear ztfp ztf10 zterm1 zterm2;
ztfp   = T_freeze(Sbr,3);
ztf10  = T_freeze(Sbr,5);
zterm1 = gsw_gibbs_ice(0,0,ztfp,0.);
zterm2 = gsw_gibbs_ice(0,0,ztf10,0.);

dmu_w_1d = zterm1 - zterm2;

%======================================================================================================
% Plots
%======================================================================================================

%--------------------------------------------
% 1- Freezing condition contours
%--------------------------------------------
figure; hold on; %mu_i - mu_w, expanded TEOS-10

v = [-6. 0.; 0. 0.; 0. 120.; -6. 120.];
f = [1 2 3 4];
patch('Faces',f,'Vertices',v,'FaceColor', [0. 0.5 0.], 'FaceAlpha', 0.1)

c1 = plot(T,S_liquidus(T,3),'LineWidth', 2,'Color', 'k');
c2 = plot(T_freeze(Sbr,4), Sbr, '--', 'LineWidth', 2, 'Color', 'b');
c3 = plot(T_freeze(Sbr,5), Sbr, 'LineWidth', 2, 'Color', 'b');

[c4,h4] = contour(TT,SS,mu_ice-mu_br1, '--', 'Color', 'b');,
%clabel(c4, h4, 'LabelSpacing', 200,'FontSize',12);

[c5,h5] = contour(TT,SS,mu_ice-gsw_chem_potential_water_t_modified(SS,TT,0.,'S',1)*1000, 'Color', 'b');,
clabel(c5, h5, 'LabelSpacing', 200,'FontSize',12);

text(-1, 60., 'TEOS-10 validity', 'Rotation', 90., 'Color', [0. 0.5 0.], 'FontSize', 16)

legend([c1 c2 c3], {'POLY3 S_{br}(T) fit', 'eTEOS-10', 'mTEOS-10'} )

ylim([0 250])
xlabel('T(C)'); ylabel('S_{br} (g/kg)');
set(gca,'fontsize', 16)
set(gca, 'FontName', 'Myriad pro')
