clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% FIGA2
%   
%=========================================================================================================

SA0 = 120. % pivotal value from which the patch starts

S    = SA0:10:250;
x   = S - SA0;
a   = 1.2370e-5
gC  = a * x.^4;
muC = gC - ( 4. * a * x.^3 ) .* S;

figure; % Figure 4 - gc and muc
subplot(1,2,1); hold on; box on; grid on
plot(S,gC/1000.,'LineWidth', 3); xlabel('S_{br} (g/kg)'); ylabel('g^c (kJ/kg)')
xlim([SA0 250.])
text(130,3.5,'(a)','fontsize', 16, 'FontWeight', 'bold')
set(gca,'fontsize', 16)
set(gca, 'FontName', 'Myriad Pro')


subplot(1,2,2); hold on
plot(S,muC/1000.,'LineWidth', 3);  ylabel('\mu^{c} (kJ/kg)'); % xlabel('S_{br} (g/kg)');
xlim([SA0 250.])
text(130,-2.5,'(b)','fontsize', 16, 'FontWeight', 'bold')
set(gca,'fontsize', 16); box on; grid on;
set(gca, 'FontName', 'Myriad Pro')


