clear all; close all
%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% TAB 4
%
%=========================================================================================================

T_eutectic = -36.2000000000000000;
S_eutectic = S_liquidus(T_eutectic,3);

%
%---------------------------------------------------------------------------------------------------------
%  Get Observations;
%---------------------------------------------------------------------------------------------------------
%

[Sbr_obs, T_obs, S_G37, T_G37, S_B16, T_B16, S_NT54, T_NT54, S_DK74, T_DK74 ] = ...
    liquidus_obs(T_eutectic); % get retained observations, truncating hypo-eutectic values

%
%---------------------------------------------------------------------------------------------------------
%  Compute and display statistics;
%---------------------------------------------------------------------------------------------------------
%

disp({'==============================================================='})
disp({' *** Differences of any fit wrt observations *** '})
disp({'==============================================================='})

disp({' * POLY3 fit '})
Sbr_3o = S_liquidus(T_obs,3);
disp({' Mean Bias : ', mean(Sbr_3o - Sbr_obs)}                )
disp({' RMSE      : ', mean( sqrt( (Sbr_3o - Sbr_obs).^2 ) )} )
disp({' STDE      : ', std(Sbr_3o - Sbr_obs)}                 )
[zR,zP] = corrcoef(Sbr_3o, Sbr_obs, 'rows', 'pairwise');
disp({' R2 = ', zR(1,2)^2})
disp({' P  = ', zP(1,2)})
format short
disp({' Eutectic salinity error = ', S_liquidus(T_eutectic,3) - S_eutectic, 'g/kg'} )
disp({' Eutectic temperature error = ', T_freeze(S_eutectic,3) - T_eutectic, 'degC'} )
format longe
disp({' *** '} )

disp({' * Assur 58 linear liquidus'})
Sbr_A58 = S_liquidus(T_obs,1);
disp({' Mean Bias : ', mean(Sbr_A58 - Sbr_obs)}                )
disp({' RMSE      : ', mean( sqrt( (Sbr_A58 - Sbr_obs).^2 ) )} )
disp({' STDE      : ', std(Sbr_A58 - Sbr_obs)}                 )
[zR,zP] = corrcoef(Sbr_A58, Sbr_obs, 'rows', 'pairwise');
disp({' R2 = ', zR(1,2)^2})
disp({' P  = ', zP(1,2)})
format short
disp({' Eutectic salinity error = ', S_liquidus(T_eutectic,1) - S_eutectic, 'g/kg'} )
disp({' Eutectic temperature error = ', T_freeze(S_eutectic,1) - T_eutectic, 'degC'} )
format longe
disp({' *** '} )

disp({' * NW09 linear liquidus'})
Sbr_NW09 = S_liquidus(T_obs,2);
disp({' Mean Bias : ', mean(Sbr_NW09 - Sbr_obs)}                )
disp({' RMSE      : ', mean( sqrt( (Sbr_NW09 - Sbr_obs).^2 ) )} )
disp({' STDE      : ', std(Sbr_NW09 - Sbr_obs)}                 )
[zR,zP] = corrcoef(Sbr_NW09, Sbr_obs, 'rows', 'pairwise');
disp({' R2 = ', zR(1,2)^2})
disp({' P  = ', zP(1,2)})
format short
disp({' Eutectic salinity error = ', S_liquidus(T_eutectic,2) - S_eutectic, 'g/kg'} )
disp({' Eutectic temperature error = ', T_freeze(S_eutectic,2) - T_eutectic, 'degC'} )
format longe
disp({' *** '} )

disp({' * mTEOS-10 liquidus'})
Sbr_mTEOS10 = S_liquidus(T_obs,5);
disp({' Mean Bias : ', mean(Sbr_mTEOS10 - Sbr_obs)}                )
disp({' RMSE      : ', mean( sqrt( (Sbr_mTEOS10 - Sbr_obs).^2 ) )} )
disp({' STDE      : ', std(Sbr_mTEOS10 - Sbr_obs)}                 )
[zR,zP] = corrcoef(Sbr_mTEOS10, Sbr_obs, 'rows', 'pairwise');
disp({' R2 = ', zR(1,2)^2})
disp({' P  = ', zP(1,2)})
format short
disp({' Eutectic salinity error = ', S_liquidus(T_eutectic,5) - S_eutectic, 'g/kg'} )
disp({' Eutectic temperature error = ', T_freeze(S_eutectic,5) - T_eutectic, 'degC'} )
format longe
disp({' *** '} )

disp({' * CW86 '})
Sbr_CW86 = S_liquidus(T_obs,6);
disp({' Mean Bias : ', nanmean(Sbr_CW86 - Sbr_obs)}                )
disp({' RMSE      : ', nanmean( sqrt( (Sbr_CW86 - Sbr_obs).^2 ) )} )
disp({' STDE      : ', nanstd(Sbr_CW86 - Sbr_obs)}                 )
[zR,zP] = corrcoef(Sbr_CW86, Sbr_obs, 'rows', 'pairwise');
disp({' R2 = ', zR(1,2)^2})
disp({' P  = ', zP(1,2)})
format short
disp({' Eutectic salinity error = ', S_liquidus(T_eutectic,6) - S_eutectic, 'g/kg'} )
disp({' Eutectic temperature error = ', T_freeze(S_eutectic,6) - T_eutectic, 'degC'} )
format longe
disp({' *** '} )

disp({' * FREZCHEM '})
Sbr_FC = S_liquidus(T_obs,7);
disp({' Mean Bias : ', mean(Sbr_FC - Sbr_obs)}                )
disp({' RMSE      : ', mean( sqrt( (Sbr_FC - Sbr_obs).^2 ) )} )
disp({' STDE      : ', std(Sbr_FC - Sbr_obs)}                 )
[zR,zP] = corrcoef(Sbr_FC, Sbr_obs, 'rows', 'pairwise');
disp({' R2 = ', zR(1,2)^2})
disp({' P  = ', zP(1,2)})
format short
disp({' Eutectic salinity error = ', S_liquidus(T_eutectic,7) - S_eutectic, 'g/kg'} )
%disp({' Eutectic temperature error = ', T_freeze(S_eutectic,7) - T_eutectic, 'degC'} )
format longe
disp({' *** '} )
