function [dTf_dS] = T_freeze_deriv_S(S,i_opt)
%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
%=========================================================================================================
%
% T_freeze_deriv_S : gets the freezing point derivative wrt S
%
% IN
%
% S                : Absolute Salinity (g/kg)
% i_opt            : 1=Assur 58; 2=Notz Worster 2009; 3=3rd order fit; 
%                    4=TEOS-10 extended; 5=TEOS-10 modified; 6=Cox Weeks 86
%
% OUT
%
% dTf_dS           : Freezing point salinity derivative (degC/(g/kg))
%
%--------------------------------------------------------------------------------------------------------
%
% Made in France by the beloved Martin Vancoppenolle (Aug 2017, Lille)
%
%=========================================================================================================

if ( i_opt == 1 ); % Bitz and Lipscomb, 1999
    
    dTf_dS      = S;
    dTf_dS( :)  = -0.05411;
    
end

if ( i_opt >= 2 );  % Numerical approximation of the derivative
    
   dS     = 1.0e-5; % chosen empirically (found best choice)
   
   dTf_dS = ( T_freeze(S+dS,i_opt) - T_freeze(S,i_opt) ) / dS;
   
end

