function [f_sm] = fs_minerals(T,i_opt,T_eutectic)

%=========================================================================================================
%
% fs_minerals : computes solid salt fraction at chemical equilibrium from different formulations
%
% IN
%
% T                : Ice Temperature (C)
% i_opt            : 0=No minerals; 1=Assur 58, 3 salts, normalized; 2=Frezchem based
% T_eutectic       : Eutectic temperature (C)
%
% OUT
%
% f_sm            : Solid salt fraction (mass fraction of total salt in minerals)
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
% Supporting material
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%   
%=========================================================================================================

%
%=========================================================================================================

if ( i_opt == 0 ) ;
    f_sm = T - T;
end

if ( i_opt == 2 ); % --- FREZCHEM DIRECT COMPUTATION
   
   % read frezchem
   rep_in      = '/Users/ioulianikolskaia/Boulot/SCIENCE/RESEARCH/TEOS10_ICE/SCRIPTS/CLEANED';
   zfile       = [ rep_in, '/', char('FREZCHEM_gitterman_0.1K.nc') ];
   T_fc        = double(ncread(zfile,'T'));
   f_sm_fc     = double(ncread(zfile,'f_ss'));
   
   i_sal       = 10; % f_sm is independent of salinity so we don't care

   f_sm         = pchip(T_fc,f_sm_fc(:,i_sal),T); % Piecewise cubic hermite interpolating polynomial

   f_sm(find(T<=T_eutectic)) = 1.;
   
end;


end % end of the script