function gc = gc_S(S,ns,i_opt)

%=========================================================================================================
%
% gc               : perturbation to Gibbs function / water chemical potential for high-salinities
%
% IN
%
% S                : absolute salinity (g/kg)
% ns               : order of "legendre" derivation
%                    (0 -> gibbs function, 1 -> chemical potential)
%   
%
% OUT
%
% gc               : perturbation to Gibbs / water chemical potential in seawater
%
%--------------------------------------------------------------------------------------------------------
%
% Made in Austria by the beloved Martin Vancoppenolle (Apr 2018, Vienna)
%
%=========================================================================================================

%------------------------------------------------------------------------------
% Polynomial coefficients
%------------------------------------------------------------------------------

SA0 = 120.;

%--- 4th polynom with guaranteed eutectic, computed by hand (fitting is simple)
if ( i_opt ==  1);
   %a = [ 0. 0. 1.236767986992330e-05 0. ];
   a = [ 0. 0. 1.2370e-05 0. ]; % OBS
   % %a = [ 0. 0. XXXX 0. ];    % POLY3
   % %a = [ 0. 0. 1.1258e-05 0. ]; % FREZCHEM
end

%--- 2-3-4 order polynom with guaranteed eutectic, fitted on R(S_obs)
if ( i_opt == 2 );
   % all data
   a = [  2.785418351115122e-02 -2.794192188978101e-04     1.319795534776623e-05 0.];
   % FREZCHEM polynom
   % a = [ 0.070277607876419 -8.57398999051744e-04 1.5293953474350e-5 0.];
end

%--- 2-3-4-5 polynom with NO eutectic, fitted on R(S_fit)
if ( i_opt == 3 );
    % all data
    a = [ 1.592540805851856e-01    -5.947056460971947e-04    -4.759651944288706e-06 9.902912575125158e-08 ];
    % FREZCHEM polynom
    % a = [ 2.892698321021526e-01    -2.872809044885969e-03     7.079645439969823e-06 7.345128796820551e-08 ];
    % all data (NT54 excluded)
    %a = [ 5.999325125764802e-02     4.753125421703239e-03    -7.409479348940116e-05 3.597134251381477e-07 ];
end

x = S-SA0; % rescaled salinity coordinate

%------------------------------------------------------------------------------
% Perturbation functions
%------------------------------------------------------------------------------

%--- Perturbation to gibbs function
if ( ns == 0 );
    gc = a(1) * x.^2 + a(2) * x.^3 + a(3) * x.^4 + a(4) * x.^5;
    gc(find(x<0)) = 0.;
end

%--- Perturbation to chemical potential
if ( ns == 1 );
    zgc = a(1) * x.^2 + a(2) * x.^3 + a(3) * x.^4;
    zdgc_ds = 2*a(1) * x + 3*a(2) * x.^2 + 4*a(3) * x.^3 + 5.*a(4) * x.^4;
    gc = zgc - S .* ( zdgc_ds ); 
    gc(find(x<0)) = 0.;
end

end