clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%   
%=========================================================================================================
% 
% liquidus_POLY3_fit.m
%
% - Put all S_liq(T) observations / model products together
%
% - Perform a n^th order fit (3rd is convenient, more overfits high salinity data)
%   Under the constrain Sbr = 0 in T=0
%
%=========================================================================================================


n = 3; % deg of the polynoms to fit

%---------------------------------------------------------------------------------------------------------
%  Get Observations;
%---------------------------------------------------------------------------------------------------------

T_eutectic = -36.2000000000000000;

[Sbr_obs, T_obs, S_G37, T_G37, S_B16, T_B16, S_NT54, T_NT54, S_DK74, T_DK74 ] = ...
    liquidus_obs(T_eutectic); % get retained observations, truncating hypo-eutectic values

%---------------------------------------------------------------------------------------------------------
% Do the fit under the constrain Sbr = 0 in T =0
%---------------------------------------------------------------------------------------------------------

x = T_obs';
y = S_obs;

x0 = 0;
y0 = 0;

% 'C' is the Vandermonde matrix for 'x'
V(:,n+1) = ones(length(x),1,class(x));
for j = n:-1:1
     V(:,j) = x.*V(:,j+1);
end

C = V;

% 'd' is the vector of target values, 'y'.
d = y;

% There are no inequality constraints in this case, i.e., 
A = [];
b = [];

% We use linear equality constraints to force the curve to hit the required point. In
% this case, 'Aeq' is the Vandermoonde matrix for 'x0'
Aeq = x0.^(n:-1:0);

% and 'beq' is the value the curve should take at that point
beq = y0;

p = lsqlin( C, d, A, b, Aeq, beq );

disp({' === Polynom coefficients for Sbr(T) === '})
format longe
p

% We can then use POLYVAL to evaluate the fitted curve
S_fit = polyval( p, x )';

%--- Evaluate the fit
disp({' Mean Bias : ', mean(S_fit - S_obs)}                )
disp({' RMSE      : ', mean( sqrt( (S_fit - S_obs).^2 ) )} )
disp({' STDE      : ', std(S_fit - S_obs)}                 )

[zR,zP] = corrcoef(S_fit, S_obs, 'rows', 'pairwise');
disp({' R2 = ', zR(1,2)^2})
disp({' P  = ', zP(1,2)})