
function [ S_RK66_exp1, T_RK66_exp1, phi_H2O_br_RK66_exp1, ...
           S_RK66_exp2, T_RK66_exp2, phi_H2O_br_RK66_exp2 ] = phi_H2O_br_obs
%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
%=========================================================================================================
%
% phi_H2O_br_obs: liquid water content in brine from the Nuclear Magnetic Resonance measurements
%                 of Richardson and Keller (1966)
%
% OUT: S_RK66_exp1, T_RK66_exp1, phi_H2O_br_RK66_exp1 
%      S_RK66_exp2, T_RK66_exp2, phi_H2O_br_RK66_exp2 
%
%      Salinity S in g/kg, Temperature T in C, liquid brine fractions phi (g/kg) 
%      from the 2 experiments of Richardson and Keller
% 
% Richardson, C., and E. E. Keller (1966), The brine content of sea ice measured with
% a nuclear magnetic resonance spectrometer, Journal of Glaciology, 6, 89?100.
%
% (c) beloved Martin Vancoppenolle, trains, 2018.
%
% SIES: Sea Ice Equation of State Routines
%
%=========================================================================================================

%---------------------------------------------------------------------------------------------------------
% Observations;
%---------------------------------------------------------------------------------------------------------

% I started using original table data.
% Yet they are likely post-processed
% in an uncontrolled fashion
% Hence I preferred to digitize the figures
%
% Direct NMR measurement gives QT/Q0, the ratios of NMR amplitudes at temperature T 
% at a reference "0" temperature where all sample is liquid
%
% Liquid H2O fraction in brine is QT/Q0 * ( 1-S/1000)

% Figure 2, page 95 (S = 35.035 g/kg)
S_RK66_exp1            =    35.035;
T_RK66_exp1            =   [ -2.211, -3.876 -4.109 -5.606 -6.868 -8.142 -8.258 -10.145 -13.401 -16.172 -20.010 -22.052 -24.118 -26.068 -32.145 -35.994 ];
QT_Q18_exp1            =   [ 0.859 0.527 0.441 0.321 0.301 0.257 0.237 0.202 0.163 0.140 0.120 0.115 0.079 0.050 0.027 0.021 ]*1000.;
phi_H2O_br_RK66_exp1   =   QT_Q18_exp1 * ( 1. - S_RK66_exp1/1000. );

% Figure 3, page 96 (S = 10.022 g/kg)
S_RK66_exp2            =   10.022;
T_RK66_exp2            =   [ -1.065 -4.647 -10.644 -15.965 -18.567 -22.801 -25.027  ];
QT_Q18_exp2            =   [ 0.596 0.116 0.052 0.041 0.036 0.025 0.019 ]*1000.;
phi_H2O_br_RK66_exp2   =   QT_Q18_exp2 * ( 1. - S_RK66_exp2/1000. );

end