function [frezchem] = read_frezchem

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
%=========================================================================================================
% 
% read_frezchem
% - reads the FREZCHEM phase diagram
%
% (c) beloved Martin Vancoppenolle, trains, 2018.
%
% SIES: Sea Ice Equation of State Routines
%
%=========================================================================================================


rep_in  = '/Users/ioulianikolskaia/Boulot/SCIENCE/RESEARCH/TEOS10_ICE/SCRIPTS/Vancoppenolle_et_al_JGR19_materials';
zfile   = [ rep_in, '/', char('FREZCHEM_phasediagram_v1.nc') ];

%---------------------------------------
% extract frezchem phase diagram fields
%---------------------------------------

frezchem.T           = double(ncread(zfile,'T'));
frezchem.SA          = double(ncread(zfile,'SA'));
frezchem.IS          = double(ncread(zfile,'I'))';
frezchem.rho         = double(ncread(zfile,'rho'))';
frezchem.OC          = double(ncread(zfile,'Osm_coeff'))';
frezchem.pH          = double(ncread(zfile,'pH'))';
frezchem.nit         = ncread(zfile,'nit')';
frezchem.M_tot       = double(ncread(zfile,'M_tot'))';
frezchem.M_ice       = double(ncread(zfile,'M_Ice'))';
frezchem.M_H2O_liq   = double(ncread(zfile,'M_H2O_liq'))';
frezchem.M_H2O_min   = double(ncread(zfile,'M_H2O_min'))';
frezchem.M_salt_liq  = double(ncread(zfile,'M_salt_liq'))';
frezchem.M_salt_min  = double(ncread(zfile,'M_salt_min'))';
frezchem.S_br        = double(ncread(zfile,'S_br'))';
frezchem.S_ss        = double(ncread(zfile,'S_sm'))';
frezchem.f_ss        = double(ncread(zfile,'f_sm'))';
frezchem.phi_ice     = double(ncread(zfile,'phi_ice'))';
frezchem.phi_H2O_liq = double(ncread(zfile,'phi_H2O_liq'))';
frezchem.phi_H2O_min = double(ncread(zfile,'phi_H2O_min'))';
frezchem.phi_salt_liq= double(ncread(zfile,'phi_salt_liq'))';
frezchem.phi_salt_min= double(ncread(zfile,'phi_salt_min'))';
frezchem.phi_liq     = double(ncread(zfile,'phi_liq'))';
frezchem.phi_solid   = double(ncread(zfile,'phi_solid'))';
frezchem.phi_H2O     = double(ncread(zfile,'phi_H2O'))';
frezchem.phi_salt    = double(ncread(zfile,'phi_salt'))';
frezchem.phi_tot     = double(ncread(zfile,'phi_tot'))';
frezchem.conc_solute = double(ncread(zfile,'conc_solute'));
frezchem.conc_solid  = double(ncread(zfile,'conc_solid'));
frezchem.mf_solute   = double(ncread(zfile,'mf_solute'));
frezchem.mf_solid    = double(ncread(zfile,'mf_solid'));

% read solute names
filename = '/Users/ioulianikolskaia/Boulot/SCIENCE/RESEARCH/TEOS10_ICE/SCRIPTS/Vancoppenolle_et_al_JGR19_materials/solute_names.txt';
delimiter = ' ';
formatSpec = '%f%s%[^\n\r]';
fileID = fopen(filename,'r');
dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'TextType', 'string',  'ReturnOnError', false);
fclose(fileID);
zzz = table(dataArray{1:end-1}, 'VariableNames', {'VarName1','NA'});
frezchem.solute_name = string(table2cell(zzz(:,2)))
clearvars filename delimiter formatSpec fileID dataArray ans;

% read solid minearal names
filename = '/Users/ioulianikolskaia/Boulot/SCIENCE/RESEARCH/TEOS10_ICE/SCRIPTS/Vancoppenolle_et_al_JGR19_materials/solid_names.txt';
delimiter = ' ';
formatSpec = '%f%s%[^\n\r]';
fileID = fopen(filename,'r');
dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true, 'TextType', 'string',  'ReturnOnError', false);
fclose(fileID);
zzz = table(dataArray{1:end-1}, 'VariableNames', {'VarName1','NA'});
frezchem.solid_name =string(table2cell(zzz(:,2)))
clearvars filename delimiter formatSpec fileID dataArray ans;

end